@@ -922,3 +922,139 @@ def HeadOrientation(data, step, head = "cervical", tail = "tailBase", **kwargs):
         ax.tick_params(axis='both', which='major', labelsize=fontsize)
         if invertY == True:
             ax.invert_yaxis()        
+
+def SignalSubset(sig_data,freq,fields, **kwargs):
+    """
+    Performs the extraction of substes from electrophysiology data. For proper functioning, the 
+    data must be organized in a data. To subset the data with its own list of markers, the 
+    variable fields must be empty (fields = None).
+
+    Parameters
+    ----------
+    sig_data : pandas DataFrame
+        The input electrophysiology data organized with the channels in columns. We use the function
+        LFP().
+    freq : pandas DataFrame
+        Frequency of electrophysiology data collection.
+    fields : str
+        Event time markers. Developed to use the output of the "Interaction()" function. But with 
+        standardized data like the output of this function, it is possible to assemble the dataframe.
+    start_time : list, optional
+        Moment of the video you want subset to start, in seconds. If the variable is empty (None), 
+        the entire video will be processed.
+    end_time : list, optional
+        Moment of the video you want subset to end, in seconds. If the variable is empty (None), 
+        the entire video will be processed.
+        
+    Returns
+    -------
+    out : dict
+        Dictionary with the objects/places passed in the input, inside each one will have the channels
+        passed with the subset of the data.
+
+    See Also
+    --------
+    For more information and usage examples: https://github.com/pyratlib/pyrat
+
+    Notes
+    -----
+    This function was based using data from the electrophysiology plexon. Input data was formatted using
+    the LFP() function.""" 
+
+    start_time= kwargs.get('start_time')
+    end_time = kwargs.get('end_time')
+
+    if type(fields) == type(None):
+        dicts = {}
+        if type(start_time) == type(None):
+            keys = range(len(end_time))
+        else:
+            keys = range(len(start_time))
+        for j in keys:
+            cortes = {}
+            for ç,canal in enumerate(sig_data.columns):
+                if type(start_time) == type(None):
+                    for i in range(len(end_time)):
+                        cortes[ç] = sig_data[canal][None:end_time[i]*freq]
+                        dicts[j] = cortes 
+                elif type(end_time) == type(None):
+                    for i in range(len(start_time)):
+                        cortes[ç] = sig_data[canal][start_time[i]*freq:None]
+                        dicts[j] = cortes 
+                else: 
+                    for i in range(len(start_time)):
+                        cortes[ç] = sig_data[canal][start_time[i]*freq:end_time[i]*freq]
+                        dicts[j] = cortes 
+
+    else:
+        lista = []
+        start = []
+        end = []
+
+        for i in fields['obj'].unique():
+            if i != 0:
+                start.append(fields.start.loc[(fields.obj == i)].values)
+                end.append(fields.end.loc[(fields.obj == i)].values)
+                lista.append((start,end))
+
+        dicts = {}
+        keys = range(len(list(interação['obj'].unique())[1:]))
+
+        for j in keys:
+            cortes = {}
+            for ç,canal in enumerate(sig_data.columns):
+                for i in range(len(lista[0][0][j])):
+                    cortes[ç] = sig_data[canal][int(lista[0][0][j][i]*freq):int(lista[0][1][j][i]*freq)]
+                    dicts[j] = cortes
+
+    return dicts
+
+def LFP(data):
+    """
+    Performs LFP data extraction from a MATLAB file (.mat) and returns all channels arranged in 
+    columns of a DataFrame. This data was converted from a plexon file (.plx).
+
+    Parameters
+    ----------
+    data : .mat
+        Plexon data in .mat format
+       
+    Returns
+    -------
+    out : pandas DataFrame
+        A DataFrame with the data arranged in columns by channels.
+
+    See Also
+    --------
+    For more information and usage examples: https://github.com/pyratlib/pyrat
+
+    Notes
+    -----
+    This function was based using data from the electrophysiology plexon. Input data was formatted using
+    the LFP() function.""" 
+
+    import numpy as np
+    column_name = []
+    if len(data['allad'][0]) == 192:
+        time = np.arange(0,len(data['allad'][0][128])/data['adfreq'][0][0],1/data['adfreq'][0][0]) 
+        values = np.zeros((len(data['allad'][0][128]),64))
+        ç = 128
+        for j in range(64):
+            for r in range(len(data['allad'][0][128])):
+                values[r][j] = data['allad'][0][ç][r]
+            column_name.append(data['adnames'][ç])
+            ç +=1
+    elif len(data['allad'][0]) == 96:
+        time = np.arange(0,len(data['allad'][0][64])/data['adfreq'][0][0],1/data['adfreq'][0][0]) 
+        values = np.zeros((len(data['allad'][0][64]),32))
+        ç = 64
+        for j in range(32):
+            for r in range(len(data['allad'][0][64])):
+                values[r][j] = data['allad'][0][ç][r]
+            column_name.append(data['adnames'][ç])
+            ç +=1
+
+    df = pd.DataFrame(values,columns=column_name,index= None) 
+    df.insert(0, "Time", time, True)
+
+    return df  
